@@ -1,9 +1,11 @@
+# -*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 """Provides base document support."""
 import collections
 from bson.json_util import dumps, loads
 from tavi.errors import Errors
 from tavi.base.fields import BaseField
-import tavi
+
 
 def get_field_attr(cls, field):
     """Custom function for retrieving a tavi.field attribute. Handles nested
@@ -18,14 +20,19 @@ def get_field_attr(cls, field):
     else:
         return value
 
+
 def set_field_attr(cls, field, value):
     """Custom function for setting a tavi.field attribute."""
     field_descriptor = cls._field_descriptors[field]
-    if not value: value = field_descriptor.default
-    if isinstance(field_descriptor , tavi.fields.EmbeddedField) and not value: value = {}
-    if isinstance(value, dict): value = field_descriptor.doc_class(**value)
+    if not value:
+        value = field_descriptor.default
+
+    if isinstance(value, dict):
+        value = field_descriptor.doc_class(**value)
+
     setattr(cls, field, value)
 
+
 class BaseDocumentMetaClass(type):
     """MetaClass for BaseDocuments. Handles initializing the list of fields for
     the BaseDocument.
@@ -35,13 +42,14 @@ class BaseDocumentMetaClass(type):
         super(BaseDocumentMetaClass, cls).__init__(name, bases, attrs)
 
         sorted_fields = sorted(
-            [field for field in attrs.iteritems() if isinstance(field[1],
-                BaseField) and field[1].persist],
-            key = lambda i: i[1].creation_order
+            [field for field in attrs.iteritems()
+                if isinstance(field[1], BaseField) and field[1].persist],
+            key=lambda i: i[1].creation_order
         )
 
         cls._field_descriptors = collections.OrderedDict(sorted_fields)
 
+
 class BaseDocument(object):
     """Base class for Mongo Documents. Provides basic field support."""
     __metaclass__ = BaseDocumentMetaClass
@@ -49,17 +57,29 @@ class BaseDocument(object):
     def __init__(self, **kwargs):
         self._errors = Errors()
         for field in self.fields:
-            field_descriptor = self._field_descriptors[field]
             set_field_attr(self, field, kwargs.get(field))
 
-            field_value = getattr(self, field)
-            if hasattr(field_value, "owner"):
-                field_value.owner = self
+    @property
+    def fields(self):
+        """Returns the list of fields for the Document."""
+        return self._field_descriptors.keys()
 
     @property
     def field_values(self):
         """Returns a dictionary containing all fields and their values."""
-        return { field: get_field_attr(self, field) for field in self.fields }
+        return {field: get_field_attr(self, field) for field in self.fields}
+
+    @property
+    def mongo_field_values(self):
+        """Same as field_values except uses the Mongo field names. This way
+        the document can have a field name that is different from the
+        field name persisted in Mongo.
+
+        """
+        return {
+            v.name: get_field_attr(self, k)
+            for k, v in self._field_descriptors.items()
+        }
 
     @property
     def errors(self):
@@ -69,11 +89,6 @@ class BaseDocument(object):
         """
         return self._errors
 
-    @property
-    def fields(self):
-        """Returns the list of fields for the Document."""
-        return self._field_descriptors.keys()
-
     @property
     def valid(self):
         """Indicates if all the fields in the Document are valid."""
@@ -85,7 +100,9 @@ class BaseDocument(object):
 
         """
         if fields:
-            return dumps({ field: self.field_values[field] for field in fields })
+            return dumps({
+                field: self.field_values[field] for field in fields
+            })
         else:
             return dumps(self.field_values)
 
